==> dylink-generator-2.1.0.27.RELEASE-sources.jar: cn/net/vidyo/framework/builder/template/Template.java <==
package cn.net.vidyo.framework.builder.template;

public class Template implements ITemplate{
    String name="";
    String path="";
    String namespace="";
    String templatePath="";
    String prefix="";
    String fileName="entityName";
    String postfix="";
    boolean pathAddEntity=false;

    @Override
    public boolean isPathAddEntity() {
        return pathAddEntity;
    }

    public void setPathAddEntity(boolean pathAddEntity) {
        this.pathAddEntity = pathAddEntity;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    @Override
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @Override
    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    @Override
    public String getNamespace() {
        return namespace;
    }

    public void setNamespace(String namespace) {
        this.namespace = namespace;
    }

    @Override
    public String getTemplatePath() {
        return templatePath;
    }

    public void setTemplatePath(String templatePath) {
        this.templatePath = templatePath;
    }

    @Override
    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    @Override
    public String getPostfix() {
        return postfix;
    }

    public void setPostfix(String postfix) {
        this.postfix = postfix;
    }
}

==> dylink-generator-2.1.0.41.RELEASE-sources.jar: cn/net/vidyo/framework/builder/template/Template.java <==
package cn.net.vidyo.framework.builder.template;

public class Template implements ITemplate{
    boolean fileNameAddTableName =true;
    String name="";
    String path="";
    String namespace="";
    String templatePath="";
    String abstractTemplatePath="";
    String prefix="";
    String fileName="entityName";
    String postfix="";
    boolean pathAddEntity=false;

    @Override
    public String getAbstractTemplatePath() {
        return abstractTemplatePath;
    }

    public void setAbstractTemplatePath(String abstractTemplatePath) {
        this.abstractTemplatePath = abstractTemplatePath;
    }

    public boolean isFileNameAddTableName() {
        return fileNameAddTableName;
    }

    public void setFileNameAddTableName(boolean fileNameAddTableName) {
        this.fileNameAddTableName = fileNameAddTableName;
    }

    @Override
    public boolean isPathAddEntity() {
        return pathAddEntity;
    }

    public void setPathAddEntity(boolean pathAddEntity) {
        this.pathAddEntity = pathAddEntity;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    @Override
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @Override
    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    @Override
    public String getNamespace() {
        return namespace;
    }

    public void setNamespace(String namespace) {
        this.namespace = namespace;
    }

    @Override
    public String getTemplatePath() {
        return templatePath;
    }

    public void setTemplatePath(String templatePath) {
        this.templatePath = templatePath;
    }

    @Override
    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    @Override
    public String getPostfix() {
        return postfix;
    }

    public void setPostfix(String postfix) {
        this.postfix = postfix;
    }
}
